@@ -1,21 +1,24 @@
+from author.decorators import with_author
 from django.db import models
+from django_extensions.db.models import TimeStampedModel
 
 
-class PayPalPayment(models.Model):
+@with_author
+class PayPalPayment(TimeStampedModel, models.Model):
     order = models.ForeignKey(
-        'plans.Order',
+        "plans.Order",
         on_delete=models.CASCADE,
         null=False,
         blank=False,
     )
     user_plan = models.ForeignKey(
-        'plans.UserPlan',
+        "plans.UserPlan",
         on_delete=models.CASCADE,
         null=False,
         blank=False,
     )
     paypal_ipn = models.OneToOneField(
-        'ipn.PayPalIpn',
+        "ipn.PayPalIpn",
         on_delete=models.CASCADE,
         null=False,
         blank=False,
